# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2020, 2021 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""pytest-REANA."""

from __future__ import absolute_import, print_function

from .version import __version__

__all__ = ("__version__",)



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2019, 2020, 2021 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Pytest fixtures for REANA."""

from __future__ import absolute_import, print_function

import base64
import json
import os
import shutil
from uuid import uuid4

import pkg_resources
import pytest
from kombu import Connection, Exchange, Queue
from kubernetes import client
from mock import Mock, patch
from reana_commons.consumer import BaseConsumer
from reana_db.utils import build_workspace_path
from sqlalchemy import create_engine
from sqlalchemy.schema import CreateSchema
from sqlalchemy_utils import create_database, database_exists


@pytest.yield_fixture(scope="module")
def tmp_shared_volume_path(tmpdir_factory):
    """Fixture temporary file system database.

    Scope: module

    This fixture offers a temporary shared file system using
    ``tmpdir_factory.mktemp`` named ``reana`` and when scoped is finished
    it will be deleted.

    .. code-block:: python

        import os

        def test_dir_exists(tmp_shared_volume_path):
            path = os.path.join(
                tmp_shared_volume_path, 'directory_path')
            assert os.path.exists(path)

    """
    shared_volume_path = os.getenv("SHARED_VOLUME_PATH", "")
    temp_path = None
    if not os.path.exists(shared_volume_path):
        temp_path = str(tmpdir_factory.mktemp("reana"))
    yield temp_path or shared_volume_path
    if temp_path:
        shutil.rmtree(temp_path)


@pytest.fixture()
def session():
    """Create a SQL Alchemy session.

    Scope: function

    This fixture offers a SQLAlchemy session which has been created from the
    ``db_engine`` fixture.

    .. code-block:: python

        from reana_db.models import Workflow

        def test_create_workflow(session):
            workflow = Workflow(...)
            session.add(workflow)
            session.commit()
    """
    from reana_db.database import Session

    yield Session
    Session.close()


@pytest.fixture()
def app(base_app):
    """Flask application fixture.

    Scope: function

    This fixture offers a Flask application with already a database connection
    and all the models created. When finished it will delete all models.

    .. code-block:: python

        def create_ninja_turtle()
            with app.test_client() as client:
                somedata = 'ninja turtle'
                res = client.post(url_for('api.create_object'),
                                  content_type='application/json',
                                  data=json.dumps(somedata))

                assert res.status_code == 200

    """
    from reana_db.database import Session
    from reana_db.models import Base, Resource

    engine = create_engine(base_app.config["SQLALCHEMY_DATABASE_URI"])
    base_app.session.bind = engine
    with base_app.app_context():
        if not engine.dialect.has_schema(engine, "__reana"):
            engine.execute(CreateSchema("__reana"))
        if not database_exists(engine.url):
            create_database(engine.url)
        Base.metadata.create_all(bind=engine)
        Resource.initialise_default_resources()
        yield base_app
        Session.close()  # close hanging connections
        Base.metadata.drop_all(bind=engine)


@pytest.fixture()
def default_user(app, session):
    """Create users.

    Scope: function

    This fixture creates an user with a default UUID
    ``00000000-0000-0000-0000-000000000000``, ``email`` `info@reana.io`
    and ``access_token`` ``secretkey`` and returns it.

    .. code-block:: python

        def test_default_user_exists(default)
            with app.test_client() as client:
                res = client.post(url_for('api.get_users'),
                                  query_string={"user": default_user.id_})

                assert res.status_code == 200


    """
    from reana_db.models import User

    default_user_id = "00000000-0000-0000-0000-000000000000"
    user = User.query.filter_by(id_=default_user_id).first()
    if not user:
        with patch("reana_db.database.Session", return_value=session):
            user = User(
                id_=default_user_id, email="info@reana.io", access_token="secretkey"
            )
        session.add(user)
        session.commit()
    return user


@pytest.fixture()
def serial_workflow():
    """Create a serial workflow.

    Scope: function

    This fixture provides a ``serial`` workflow.
    """
    return {
        "reana_specification": {
            "workflow": {
                "specification": {
                    "steps": [
                        {
                            "environment": "reanahub/reana-env-jupyter",
                            "commands": ["echo 'Hello REANA'"],
                        }
                    ]
                },
                "type": "serial",
            },
        },
    }


@pytest.fixture()
def cwl_workflow_with_name():
    """CWL workflow with name.

    Scope: function

    This fixture provides a ``CWL`` workflow with a name as a dictionary.
    """
    return {
        "reana_specification": {
            "inputs": {"parameters": {"min_year": "1991", "max_year": "2001"}},
            "workflow": {
                "specification": {"first": "do this", "second": "do that"},
                "type": "cwl",
            },
            "type": "cwl",
        },
        "workflow_name": "my_test_workflow",
    }


@pytest.fixture()
def yadage_workflow_with_name():
    """Yadage workflow with name.

    Scope: function

    This fixture provides a ``yadage`` workflow with a name as a dictionary.
    """
    return {
        "reana_specification": {
            "workflow": {
                "specification": {"first": "do this", "second": "do that"},
                "type": "yadage",
            },
            "inputs": {"parameters": {"min_year": "1991", "max_year": "2001"}},
            "type": "yadage",
        },
        "name": "my_test_workflow",
    }


@pytest.fixture()
def cwl_workflow_without_name():
    """CWL workflow without name.

    Scope: function

    This fixture provides a ``CWL`` workflow without a name as a dictionary.
    """
    return {
        "reana_specification": {
            "inputs": {"parameters": {"min_year": "1991", "max_year": "2001"}},
            "workflow": {
                "specification": {"first": "do this", "second": "do that"},
                "type": "cwl",
            },
            "type": "cwl",
        },
        "name": "",
    }


@pytest.fixture()
def yadage_workflow_without_name():
    """Yadage workflow without name.

    Scope: function

    This fixture provides a ``yadage`` workflow without name as a dictionary.
    """
    return {
        "reana_specification": {
            "workflow": {
                "specification": {"first": "do this", "second": "do that"},
                "type": "yadage",
            },
            "inputs": {"parameters": {"min_year": "1991", "max_year": "2001"}},
            "type": "yadage",
        },
        "name": "",
    }


@pytest.fixture()
def yadage_workflow_spec_loaded():
    """Nested Yadage workflow.

    Scope: function

    This fixture provides a nested ``yadage`` workflow spec loaded as dictionary.
    """
    return {
        "version": "0.7.2",
        "inputs": {
            "files": ["code/foo.C", "code/bar.C"],
            "directories": ["workflow/yadage"],
            "parameters": {"foo": "foo_val", "bar": "bar_val", "baz": "baz_val"},
        },
        "outputs": {"files": ["fitdata/plot.png"]},
        "workflow": {
            "type": "yadage",
            "file": "workflow/yadage/workflow.yaml",
            "specification": {
                "stages": [
                    {
                        "name": "gendata",
                        "dependencies": {
                            "dependency_type": "jsonpath_ready",
                            "expressions": ["init"],
                        },
                        "scheduler": {
                            "scheduler_type": "singlestep-stage",
                            "parameters": [
                                {
                                    "key": "foo",
                                    "value": {
                                        "step": "init",
                                        "output": "foo",
                                        "expression_type": "stage-output-selector",
                                    },
                                },
                                {
                                    "key": "bar",
                                    "value": {
                                        "step": "init",
                                        "output": "bar",
                                        "expression_type": "stage-output-selector",
                                    },
                                },
                            ],
                            "step": {
                                "process": {
                                    "process_type": "interpolated-script-cmd",
                                    "script": "python --foo '{foo}/{bar}'",
                                    "interpreter": "sh",
                                },
                                "publisher": {
                                    "publisher_type": "frompar-pub",
                                    "outputmap": {"data": "outfilename"},
                                },
                                "environment": {
                                    "environment_type": "docker-encapsulated",
                                    "image": "reanahub/reana-env-root6",
                                    "imagetag": "6.18.04",
                                    "resources": [],
                                    "envscript": "",
                                    "env": {},
                                    "workdir": None,
                                    "par_mounts": [],
                                },
                            },
                        },
                    },
                    {
                        "name": "fitdata",
                        "dependencies": {
                            "dependency_type": "jsonpath_ready",
                            "expressions": ["gendata"],
                        },
                        "scheduler": {
                            "scheduler_type": "singlestep-stage",
                            "parameters": [
                                {
                                    "key": "baz",
                                    "value": {
                                        "step": "init",
                                        "output": "baz",
                                        "expression_type": "stage-output-selector",
                                    },
                                },
                                {
                                    "key": "bar",
                                    "value": {
                                        "step": "gendata",
                                        "output": "bar",
                                        "expression_type": "stage-output-selector",
                                    },
                                },
                            ],
                            "step": {
                                "process": {
                                    "process_type": "interpolated-script-cmd",
                                    "script": 'root -b -q \'("{baz}","{bar}")\'',
                                    "interpreter": "sh",
                                },
                                "publisher": {
                                    "publisher_type": "frompar-pub",
                                    "outputmap": {"plot": "outfile"},
                                },
                                "environment": {
                                    "environment_type": "docker-encapsulated",
                                    "image": "reanahub/reana-env-root6",
                                    "imagetag": "6.18.04",
                                    "resources": [],
                                    "envscript": "",
                                    "env": {},
                                    "workdir": None,
                                    "par_mounts": [],
                                },
                            },
                        },
                    },
                    {
                        "name": "parent_step",
                        "dependencies": {
                            "dependency_type": "jsonpath_ready",
                            "expressions": [""],
                        },
                        "scheduler": {
                            "scheduler_type": "singlestep-stage",
                            "parameters": [
                                {
                                    "key": "nested_foo",
                                    "value": {
                                        "step": "init",
                                        "output": "nested_foo",
                                        "expression_type": "stage-output-selector",
                                    },
                                },
                            ],
                            "workflow": {
                                "stages": [
                                    {
                                        "name": "nested_step",
                                        "dependencies": {
                                            "dependency_type": "jsonpath_ready",
                                            "expressions": ["run_mc"],
                                        },
                                        "scheduler": {
                                            "scheduler_type": "singlestep-stage",
                                            "parameters": [
                                                {
                                                    "key": "nested_foo",
                                                    "value": {
                                                        "step": "init",
                                                        "output": "nested_foo",
                                                    },
                                                },
                                                {
                                                    "key": "inputs",
                                                    "value": {
                                                        "stages": "run_mc[*].mergeallvars",
                                                        "output": "mergedfile",
                                                        "expression_type": "stage-output-selector",
                                                    },
                                                },
                                                {
                                                    "key": "mergedfile",
                                                    "value": "{workdir}/merged.root",
                                                },
                                            ],
                                            "step": {
                                                "process": {
                                                    "process_type": "interpolated-script-cmd",
                                                    "interpreter": "bash",
                                                    "script": "source /usr/local/bin/{nested_foo}.sh\nhadd {mergedfile} {inputs}\n",
                                                },
                                                "environment": {
                                                    "environment_type": "docker-encapsulated",
                                                    "image": "reanahub/reana-env-root6",
                                                    "imagetag": "6.18.04",
                                                    "resources": [],
                                                    "envscript": "",
                                                    "env": {},
                                                    "workdir": None,
                                                    "par_mounts": [],
                                                },
                                                "publisher": {
                                                    "publisher_type": "frompar-pub",
                                                    "outputmap": {
                                                        "mergedfile": "mergedfile"
                                                    },
                                                },
                                            },
                                        },
                                    }
                                ]
                            },
                        },
                    },
                ]
            },
        },
    }


@pytest.fixture()
def snakemake_workflow_spec_loaded():
    """Scatter-gather Snakemake workflow.

    Scope: function

    This fixture provides the internal representation of a basic scatter-gather ``snakemake`` workflow loaded as dictionary.
    """
    return {
        "version": "0.8.0",
        "workflow": {
            "type": "snakemake",
            "file": "workflow/snakemake/Snakemake",
            "specification": {
                "job_dependencies": {
                    "all": ["gather"],
                    "gather": ["scatterA", "scatterB"],
                    "scatterA": [],
                    "scatterB": [],
                },
                "steps": [
                    {
                        "commands": ["sleep 15 && mkdir -p results && touch {output}"],
                        "environment": "python:2.7-slim",
                        "inputs": {},
                        "kubernetes_memory_limit": None,
                        "kubernetes_uid": None,
                        "name": "scatterA",
                        "outputs": {},
                        "params": {},
                    },
                    {
                        "commands": ["sleep 30 && mkdir -p results && touch {output}"],
                        "environment": "python:2.7-slim",
                        "inputs": {},
                        "kubernetes_memory_limit": None,
                        "kubernetes_uid": None,
                        "name": "scatterB",
                        "outputs": {},
                        "params": {},
                    },
                    {
                        "commands": ["sleep 5 && touch {output}"],
                        "environment": "python:2.7-slim",
                        "inputs": {},
                        "kubernetes_memory_limit": None,
                        "kubernetes_uid": None,
                        "name": "gather",
                        "outputs": {},
                        "params": {},
                    },
                ],
            },
        },
    }


class _BaseConsumerTestIMPL(BaseConsumer):
    """Test implementation of a REANAConsumer class.

    This class is a basic implementation of a ``reana_commons.BaseConsumer``
    to use while testing. There are fixtures wrapping it so it shouldn't
    be used directly.
    """

    def get_consumers(self, Consumer, channel):
        """Sample get consumers method."""
        return [
            Consumer(
                self.queue,
                callbacks=[self.on_message],
                accept=[self.message_default_format],
            )
        ]

    def on_message(self, body, message):
        """Sample on message method."""
        message.ack()


@pytest.fixture
def ConsumerBase():
    """Return a class implementing a BaseConsumer.

    Scope: function

    This fixture offers a class which implements the
    ``reana_commons.BaseConsumer``. It will just acknowledge the received
    messages.
    """
    return _BaseConsumerTestIMPL


@pytest.fixture
def ConsumerBaseOnMessageMock(ConsumerBase):
    """Return a BaseConsumer class with ``on_message`` mocked.

    Scope: function

    This fixture offers a class which implements the
    ``reana_commons.BaseConsumer``. Additionally to the ``ConsumerBase``
    fixture, this class has an ``on_message`` mocked method so actions like
    the following can be performed.

    .. code-block:: python

        def test_msg(ConsumerBaseOnMessageMock)
            consumer = ConsumerBaseOnMessageMock()
            # 1 message is published with message {'some': 'message'}
            expected_body = {'some': 'message'}
            consumer.on_message.assert_called_once_with(
                expected, ANY)

    """
    with patch.object(ConsumerBase, "on_message"):
        yield ConsumerBase


@pytest.fixture
def consume_queue():
    """Provide a callable to consume a queue.

    Scope: function

    This fixture offers a function which given a ``kombu.Consumer`` will
    consume the messages in the queue until a certain ``limit``. If ``limit``
    is not specified it will consume uninterruptedly.

    .. code-block:: python

        def test_consume_1_msg(ConsumerBase, consume_queue)
            consumer = ConsumerBase()
            # some message is published in the queue
            # and we want to consume only one.
            consume_queue(consumer, limit=1)

    """

    def _consume_queue(consumer, limit=None):
        """Consume AMQP queue.

        :param consumer: A :class:`kombu.Consumer` to consume from.
        :param limit: Integer which represents how many items to consume
            from the queue, if not specified, the consume method will run
            uninterruptedly.
        """
        consumer_generator = consumer.consume(limit=limit)
        while True:
            try:
                next(consumer_generator)
            except StopIteration:
                # no more items to consume in the queue
                break

    return _consume_queue


@pytest.fixture(scope="session")
def in_memory_queue_connection():
    """In memory message queue.

    Scope: session

    This fixture offers an in memory :class:`kombu.Connection` scoped to the
    testing session.

    .. code-block:: python

        def test_something(ConsumerBase, in_memory_queue_connection):
            consumer = ConsumerBase(connection=in_memory_queue_connection)
            # Now you have a consumer connected to an in memory queue


    """
    return Connection("memory:///")


@pytest.fixture
def default_exchange():
    """Return a default :class:`kombu.Exchange` created from configuration.

    Scope: function

    This fixture offers a default :class:`kombu.Exchange`.
    """
    return Exchange("test-exchange", type="direct")


@pytest.fixture
def default_queue(default_exchange):
    """Return a default :class:`kombu.Queue` created from configuration.

    Scope: function

    This fixture offers a default :class:`kombu.Queue`.
    """
    return Queue(
        "test-queue", exchange=default_exchange, routing_key="test-routing-key"
    )


@pytest.fixture
def default_in_memory_producer(in_memory_queue_connection, default_exchange):
    """Rerturn a :class:`kombu.Producer` connected to in memory queue.

    Scope: function

    This fixture offers a default :class:`kombu.Producer` instantiated using
    the ``in_memory_queue_connection``.

    .. code-block:: python

        def test_publish_hello(default_in_memory_producer, default_queue):
            msg = {'hello': 'ninja turtle'}
            default_in_memory_producer.publish(msg,
                                               declare=[default_queue])

    """
    return in_memory_queue_connection.Producer(
        exchange=default_exchange, routing_key="test-routing-key", serializer="json"
    )


@pytest.fixture(scope="module")
def sample_workflow_workspace(tmp_shared_volume_path):
    """Return the directory path of a sample workspace.

    Scope: module

    Creates a sample workspace in the shared volume path. Copies contents from
    the ``tests/test_workspace`` directory.

    """

    def _create_sample_workflow_workspace(relative_workspace_path):
        empty_workspace = os.path.join(tmp_shared_volume_path, relative_workspace_path)
        if not os.path.exists(empty_workspace):
            os.makedirs(empty_workspace)
        yield empty_workspace

    return _create_sample_workflow_workspace


@pytest.fixture()
def sample_yadage_workflow_in_db(
    app,
    default_user,
    session,
    yadage_workflow_with_name,
    sample_workflow_workspace,
    tmp_shared_volume_path,
):
    """Create a sample workflow in the database.

    Scope: function

    Adds a sample yadage workflow in the DB.
    """
    from reana_db.models import Workflow

    workflow_id = uuid4()
    relative_workspace_path = build_workspace_path(
        default_user.id_, workflow_id, tmp_shared_volume_path
    )
    next(sample_workflow_workspace(relative_workspace_path))
    workflow = Workflow(
        id_=workflow_id,
        name="sample_serial_workflow_1",
        owner_id=default_user.id_,
        reana_specification=yadage_workflow_with_name["reana_specification"],
        operational_options={},
        type_=yadage_workflow_with_name["reana_specification"]["workflow"]["type"],
        logs="",
        workspace_path=relative_workspace_path,
    )
    session.add(workflow)
    session.commit()
    yield workflow
    for resource in workflow.resources:
        session.delete(resource)
    session.delete(workflow)
    session.commit()


@pytest.fixture()
def sample_serial_workflow_in_db(
    app,
    default_user,
    session,
    serial_workflow,
    sample_workflow_workspace,
    tmp_shared_volume_path,
):
    """Create a sample workflow in the database.

    Scope: function

    Adds a sample serial workflow in the DB.
    """
    from reana_db.models import Workflow

    workflow_id = uuid4()
    relative_workspace_path = build_workspace_path(
        default_user.id_, workflow_id, tmp_shared_volume_path
    )
    next(sample_workflow_workspace(relative_workspace_path))
    workflow = Workflow(
        id_=workflow_id,
        name="sample_serial_workflow_1",
        owner_id=default_user.id_,
        reana_specification=serial_workflow["reana_specification"],
        operational_options={},
        type_=serial_workflow["reana_specification"]["workflow"]["type"],
        logs="",
        workspace_path=relative_workspace_path,
    )
    session.add(workflow)
    session.commit()
    yield workflow
    for resource in workflow.resources:
        session.delete(resource)
    session.delete(workflow)
    session.commit()


def sample_condition_for_starting_queued_workflows():
    """Sample always true condition."""
    return True


def sample_condition_for_requeueing_workflows():
    """Sample always false condition."""
    return False


@pytest.fixture
def no_db_user():
    """Mock user created without using db."""
    user = Mock()
    user.id_ = uuid4()
    return user


@pytest.fixture
def user_secrets():
    """Test user secrets dictionary."""
    keytab_file = base64.b64encode(b"keytab file.")
    user_secrets = {
        "username": {"value": "reanauser", "type": "env"},
        "password": {"value": "1232456", "type": "env"},
        ".keytab": {"value": keytab_file, "type": "file"},
    }
    return user_secrets


@pytest.fixture
def empty_user_secrets():
    """Empty user secrets dictionary."""
    return {}


@pytest.fixture
def corev1_api_client_with_user_secrets(no_db_user):
    """Kubernetes CoreV1 api client with user secrets in K8s secret store.

    Scope: function

    Adds the CoreV1APIClient with example user secrets.
    """

    def make_corev1_api_client_with_user_secrets(user_secrets):
        """Callable to return.

        Should be used with one of the secret store fixtures.
        """
        corev1_api_client = Mock()
        metadata = client.V1ObjectMeta(name=str(no_db_user.id_))
        metadata.annotations = {"secrets_types": "{}"}
        user_secrets_values = {}
        secrets_types = {}
        for secret_name in user_secrets:
            # Add type metadata to secret store
            secrets_types[secret_name] = user_secrets[secret_name]["type"]
            user_secrets_values[secret_name] = user_secrets[secret_name]["value"]
        metadata.annotations["secrets_types"] = json.dumps(secrets_types)
        k8s_secrets_store = client.V1Secret(
            api_version="v1", metadata=metadata, data=user_secrets_values
        )
        corev1_api_client.read_namespaced_secret = (
            lambda name, namespace: k8s_secrets_store
        )
        return corev1_api_client

    return make_corev1_api_client_with_user_secrets



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2019, 2020, 2021, 2022 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Version information for pytest-REANA.

This file is imported by ``pytest_reana.__init__``
and parsed by ``setup.py``.
"""

from __future__ import absolute_import, print_function

__version__ = "0.9.0a2"



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2019, 2020, 2021 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Pytest plugin for REANA."""


from .fixtures import (
    ConsumerBase,
    ConsumerBaseOnMessageMock,
    app,
    consume_queue,
    corev1_api_client_with_user_secrets,
    cwl_workflow_with_name,
    cwl_workflow_without_name,
    default_exchange,
    default_in_memory_producer,
    default_queue,
    default_user,
    empty_user_secrets,
    in_memory_queue_connection,
    no_db_user,
    sample_serial_workflow_in_db,
    sample_workflow_workspace,
    sample_yadage_workflow_in_db,
    serial_workflow,
    session,
    snakemake_workflow_spec_loaded,
    tmp_shared_volume_path,
    user_secrets,
    yadage_workflow_with_name,
    yadage_workflow_without_name,
    yadage_workflow_spec_loaded,
)



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2019, 2020, 2021, 2022 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Pytest fixtures for REANA."""

from __future__ import absolute_import, print_function

import os
import re

from setuptools import find_packages, setup

readme = open("README.rst").read()
history = open("CHANGES.rst").read()

extras_require = {
    "docs": ["Sphinx>=1.4.4", "sphinx-rtd-theme>=0.1.9",],
}

extras_require["all"] = []
for key, reqs in extras_require.items():
    if ":" == key[0]:
        continue
    extras_require["all"].extend(reqs)

setup_requires = [
    "pytest-runner>=2.7",
]

install_requires = [
    "apispec>=0.21.0,<0.40",
    "black>=19.10b0,<20",
    "check-manifest>=0.25,<1",
    "checksumdir>=1.1.4,<1.2",
    "coverage>=5.0,<6.0",
    "jsonschema>=3.2.0,<4.0",
    "mock>=3.0,<4.0",
    "pika>=0.12.0,<0.13",
    "pydocstyle>=5.0.0,<6.0.0",
    "pytest-cache>=1.0,<2.0",
    "pytest-cov>=3.0.0,<4.0",
    "pytest>=6.2.5,<7.0.0",
    "reana-commons[kubernetes]>=0.9.0a1,<0.10.0",
    "reana-db>=0.9.0a1,<0.10.0",
    "swagger_spec_validator>=2.1.0,<3.0",
]
packages = find_packages()


# Get the version string. Cannot be done with import!
with open(os.path.join("pytest_reana", "version.py"), "rt") as f:
    version = re.search(r'__version__\s*=\s*"(?P<version>.*)"\n', f.read()).group(
        "version"
    )

setup(
    name="pytest-reana",
    version=version,
    description=__doc__,
    long_description=readme + "\n\n" + history,
    author="REANA",
    author_email="info@reana.io",
    url="https://github.com/reanahub/pytest-reana",
    packages=["pytest_reana",],
    zip_safe=False,
    python_requires=">=3.6",
    install_requires=install_requires,
    extras_require=extras_require,
    setup_requires=setup_requires,
    include_package_data=True,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    entry_points={"pytest11": ["reana = pytest_reana.plugin",]},
)



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2020, 2021 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.
"""REANA Pytest Commons test utilities."""

from mock import Mock
from reana_commons.api_client import BaseAPIClient


def make_mock_api_client(component):

    mock_response, mock_http_response = Mock(), Mock()
    mock_response = {}
    mock_http_response.status_code = 200
    mock_http_response.raw_bytes = b"Sample downloaded data"

    def mock_api_client(
        mock_response=mock_response, mock_http_response=mock_http_response
    ):
        mock_http_client, mock_result = Mock(), Mock()
        mock_result.result.return_value = (mock_response, mock_http_response)
        mock_http_client.request.return_value = mock_result
        mock_api_client = BaseAPIClient(component, http_client=mock_http_client)
        return mock_api_client._client

    return mock_api_client



# -*- coding: utf-8 -*-
#
# This file is part of REANA.
# Copyright (C) 2018, 2020, 2021 CERN.
#
# REANA is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""REANA-pytest-Commmons test fixtures."""


from __future__ import absolute_import, print_function

import os

import pytest


def test_tmp_shared_volume_path_fixture(testdir):
    """Make sure that pytest accepts our fixture."""

    # create a temporary pytest test module
    testdir.makepyfile(
        """
        def test_sth(tmp_shared_volume_path):
            import os
            os.path.exists(tmp_shared_volume_path)
    """
    )

    # run pytest with the following cmd args
    testdir.runpytest()
    testdir.runpytest().assert_outcomes(passed=1)
